==> of_v0.7.4_ios_release.zip: of_v0.7.4_ios_release/addons/ofxMultiTouch/src/ofxMultiTouch.cpp <==
/***********************************************************************
 
 Copyright (c) 2008, 2009, Memo Akten, www.memo.tv
 *** The Mega Super Awesome Visuals Company ***
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of MSA Visuals nor the names of its contributors 
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 * ***********************************************************************/ 


#include "ofxMultiTouch.h"
#include "ofxiPhoneApp.h"

ofxMultiTouchHandler ofxMultiTouch;

void ofxRegisterMultitouch(ofxiPhoneApp * app){
	ofAddListener(ofEvents().touchDown, app, &ofxiPhoneApp::touchDown);
	ofAddListener(ofEvents().touchUp, app, &ofxiPhoneApp::touchUp);
	ofAddListener(ofEvents().touchMoved, app, &ofxiPhoneApp::touchMoved);
	ofAddListener(ofEvents().touchDoubleTap, app, &ofxiPhoneApp::touchDoubleTap);
	ofAddListener(ofEvents().touchCancelled, app, &ofxiPhoneApp::touchCancelled);
}

void ofxUnregisterMultitouch(ofxiPhoneApp * app){
	ofRemoveListener(ofEvents().touchDown, app, &ofxiPhoneApp::touchDown);
	ofRemoveListener(ofEvents().touchUp, app, &ofxiPhoneApp::touchUp);
	ofRemoveListener(ofEvents().touchMoved, app, &ofxiPhoneApp::touchMoved);
	ofRemoveListener(ofEvents().touchDoubleTap, app, &ofxiPhoneApp::touchDoubleTap);
	ofRemoveListener(ofEvents().touchCancelled, app, &ofxiPhoneApp::touchCancelled);
}

==> of_v0.8.0_ios_release.zip: of_v0.8.0_ios_release/addons/ofxMultiTouch/src/ofxMultiTouch.cpp <==
/***********************************************************************
 
 Copyright (c) 2008, 2009, Memo Akten, www.memo.tv
 *** The Mega Super Awesome Visuals Company ***
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of MSA Visuals nor the names of its contributors 
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 * ***********************************************************************/ 


#include "ofxMultiTouch.h"
#include "ofxiOSApp.h"

ofxMultiTouchHandler ofxMultiTouch;

void ofxRegisterMultitouch(ofxiOSApp * app){
	ofAddListener(ofEvents().touchDown, app, &ofxiOSApp::touchDown);
	ofAddListener(ofEvents().touchUp, app, &ofxiOSApp::touchUp);
	ofAddListener(ofEvents().touchMoved, app, &ofxiOSApp::touchMoved);
	ofAddListener(ofEvents().touchDoubleTap, app, &ofxiOSApp::touchDoubleTap);
	ofAddListener(ofEvents().touchCancelled, app, &ofxiOSApp::touchCancelled);
}

void ofxUnregisterMultitouch(ofxiOSApp * app){
	ofRemoveListener(ofEvents().touchDown, app, &ofxiOSApp::touchDown);
	ofRemoveListener(ofEvents().touchUp, app, &ofxiOSApp::touchUp);
	ofRemoveListener(ofEvents().touchMoved, app, &ofxiOSApp::touchMoved);
	ofRemoveListener(ofEvents().touchDoubleTap, app, &ofxiOSApp::touchDoubleTap);
	ofRemoveListener(ofEvents().touchCancelled, app, &ofxiOSApp::touchCancelled);
}
